'use strict'

const DEFAULT_OPTION = {
  chunks: [/./],
  attributes: {}
}

function preProcessOptions (options) {
  const newOptions = Object.assign({}, DEFAULT_OPTION, options)
  newOptions.chunks = convertToArray(newOptions.chunks)
  return newOptions
}

function convertToArray (value) {
  if (typeof value === 'string') {
    return [value]
  }
  if (value instanceof RegExp) {
    return [value]
  }
  if (Array.isArray(value)) {
    return value
  }
  return []
}

function matches (toMatch, matchers) {
  return matchers.some((matcher) => {
    if (matcher instanceof RegExp) {
      return matcher.test(toMatch)
    } else {
      return toMatch.includes(matcher)
    }
  })
}

function getScriptName (tag) {
  let name = tag.attributes.src
  if (name.includes('/')) {
    name = name.replace(/^.*\//, '')
  }
  return name
}

class ScriptAttrHtmlWebpackPlugin {
  constructor (options) {
    this.options = preProcessOptions(options)
  }

  apply (compiler) {
    compiler.plugin('compilation', (compilation) => {
      compilation.plugin('html-webpack-plugin-alter-asset-tags', (pluginArgs, callback) => {
        pluginArgs.head.forEach((tag) => {
          if (tag.tagName === 'script') {
            this.updateScript(tag)
          }
        })
        pluginArgs.body.forEach((tag) => {
          if (tag.tagName === 'script') {
            this.updateScript(tag)
          }
        })
        callback(null, pluginArgs)
      })
    })
  }

  updateScript (tag) {
    const options = this.options
    const scriptName = getScriptName(tag)
    if (matches(scriptName, options.chunks)) {
      tag.attributes = Object.assign({}, tag.attributes, options.attributes)
    }
  }
}

module.exports = ScriptAttrHtmlWebpackPlugin
